#! /bin/ksh

# this script can be used to test the package
# anyway it is still very incomplete, feel free to improve
# (and submit your improvements)

LOCKFILE1=/tmp/halockrun.1

echo "checking halockrun -t"
(./halockrun -c ${LOCKFILE1} sleep 1000; rm -r ${LOCKFILE1}) &

sleep 1
if [ ! -f ${LOCKFILE1} ]; then
	echo "fail 1: lockfile not created"
	exit 1
fi

./halockrun -t ${LOCKFILE1}
RS=$?

if [ $RS != 1 ]; then
	echo "fail 2: lockfile not locked (using -t), RS=$RS"
	exit 2
fi

./halockrun -nN ${LOCKFILE1}
RS=$?

if [ $RS != 1 ]; then
	echo "fail 2B: lockfile not locked (using -nN), RS=$RS"
	exit 2
fi


RV=`./halockrun -t ${LOCKFILE1}`
E=$?

if [ -z "${RV}" ]; then
	echo "fail 4: returned nothing on locked file"
	exit 4
fi

if [ ${RV} == 0 ]; then
	echo "fail 5: returned zero on locked file"
	exit 5
fi

if [ $E -ne 1 ]; then
	echo "fail 5A: returned $E on locked file (expected 1)"
	exit 5
fi

./halockrun -t -E 2 ${LOCKFILE1}
E=$?

if [ $E -ne 2 ]; then
	echo "fail 5B: returned $E on locked file (expected 2)"
	exit 5
fi

./halockrun -nN -E 2 ${LOCKFILE1}
E=$?

if [ $E -ne 2 ]; then
	echo "fail 5C: returned $E on locked file (expected 2)"
	exit 5
fi

kill `./halockrun -t ${LOCKFILE1}`

sleep 1

if [ -f ${LOCKFILE1} ]; then
	echo "fail 3: lockfile not removed"
	exit 3
fi

touch ${LOCKFILE1}

./halockrun -t ${LOCKFILE1}
RS=$?

if [ $RS != 0 ]; then
	echo "fail 6: not locked but return code is ${RS}"
	exit 6
fi

./halockrun -nN ${LOCKFILE1}
RS=$?

if [ $RS != 0 ]; then
	echo "fail 6B: not locked but return code is ${RS}"
	exit 6
fi


RV=`./halockrun -t ${LOCKFILE1}`

if [ ! -z "${RV}" ]; then
	echo "fail 7: not locked but stdout ist ${RV}"
	exit 7
fi

rm -f ${LOCKFILE1}


./halockrun -t -E 2 ${LOCKFILE1}
E=$?

if [ $E -ne 99 ]; then
	echo "fail 8: returned $E on error (expected 99)"
	exit 8
fi

./halockrun -nN -E 2 ${LOCKFILE1}
E=$?

if [ $E -ne 99 ]; then
	echo "fail 8B: returned $E on error (expected 99)"
	exit 8
fi


./halockrun -t -e 3 -E 2 ${LOCKFILE1}
E=$?

if [ $E -ne 3 ]; then
	echo "fail 9: returned $E on error (expected 3)"
	exit 9
fi


./halockrun -Nn -e 3 -E 2 ${LOCKFILE1}
E=$?

if [ $E -ne 3 ]; then
	echo "fail 9B: returned $E on error (expected 3)"
	exit 9
fi


#####
# test -a for bad commands

./halockrun -c ${LOCKFILE1} /command/does/not/exist
E=$?

if [ $E -ne 99 ]; then
	echo "fail 10: returned $E on error (expected 99)"
	exit 10
fi


./halockrun -ca ${LOCKFILE1} /command/does/not/exist
E=$?

if [ $E -ne 99 ]; then
	echo "fail 10B: returned $E on error (expected 99)"
	exit 10
fi


#####
# testing hatimerun

./hatimerun -k INT -t 1 sleep 10
E=$?
if [ $E -ne 99 ]; then
	echo "fail 11: returned $E on error (expected 99)"
	exit 11
fi

./hatimerun -e 99 -e 100 -k INT -t 1 -t 2 ./printsignal 2
E=$?
if [ $E -ne 99 ]; then
	echo "fail 11: returned $E on error (expected 99)"
	exit 11
fi


./hatimerun -e 99 -e 100 -k INT -t 1 -t 2 ./printsignal 10
E=$?
if [ $E -ne 100 ]; then
	echo "fail 11: returned $E on error (expected 99)"
	exit 11
fi


./hatimerun -e 99 -e 100 -k INT -t 1:0 -k TERM -t 2 ./printsignal 90 > ${LOCKFILE1}
E=$?
if [ $E -ne 100 ]; then
	echo "fail 11: returned $E on error (expected 99)"
	exit 11
fi

while read blah1 blah2 sig blah3 sec moreblah; do
	if [ "x$sig" == "xis" -o "x$sig" == "xseconds" ]; then
		/bin/true
	else
		if [ "$sec" -ge 59 -a "$sec" -le 63 ]; then
			/bin/true
		else
			echo "fail 12: time mismatch ($sec)"
			exit 12
		fi;
	fi;
done < ${LOCKFILE1}







echo "tests ok"
